@@ -26,7 +26,7 @@
 #endif
 
 #include <gnuradio/io_signature.h>
-#include <grgsm/gsmtap.h>
+#include <gsm/gsmtap.h>
 #include "stdio.h"
 #include "tch_f_decoder_impl.h"
 
@@ -92,7 +92,7 @@ namespace gr {
     {
         //setup input/output ports
         message_port_register_in(pmt::mp("bursts"));
-        set_msg_handler(pmt::mp("bursts"), boost::bind(&tch_f_decoder_impl::decode, this, _1));
+        set_msg_handler(pmt::mp("bursts"), boost::bind(&tch_f_decoder_impl::decode, this, boost::placeholders::_1));
         message_port_register_out(pmt::mp("msgs"));
         message_port_register_out(pmt::mp("voice"));    
 
