@@ -26,8 +26,8 @@
 
 #include <gnuradio/io_signature.h>
 #include "tch_f_chans_demapper_impl.h"
-#include <grgsm/endian.h>
-#include <grgsm/gsmtap.h>
+#include <gsm/endian.h>
+#include <gsm/gsmtap.h>
 
 #define BURST_SIZE 148
 
@@ -58,7 +58,7 @@ namespace gr {
         //        }
 
         message_port_register_in(pmt::mp("bursts"));
-        set_msg_handler(pmt::mp("bursts"), boost::bind(&tch_f_chans_demapper_impl::filter_tch_chans, this, _1));
+        set_msg_handler(pmt::mp("bursts"), boost::bind(&tch_f_chans_demapper_impl::filter_tch_chans, this, boost::placeholders::_1));
         message_port_register_out(pmt::mp("tch_bursts"));
         message_port_register_out(pmt::mp("acch_bursts"));
     }
