@@ -28,8 +28,8 @@
 #include "burst_sink_impl.h"
 #include <stdio.h>
 #include <sstream>
-#include <grgsm/endian.h>
-#include <grgsm/gsmtap.h>
+#include <gsm/endian.h>
+#include <gsm/gsmtap.h>
 
 namespace gr {
   namespace gsm {
@@ -51,7 +51,7 @@ namespace gr {
         d_bursts(pmt::PMT_NIL)
     {
         message_port_register_in(pmt::mp("in"));
-        set_msg_handler(pmt::mp("in"), boost::bind(&burst_sink_impl::process_burst, this, _1));
+        set_msg_handler(pmt::mp("in"), boost::bind(&burst_sink_impl::process_burst, this, boost::placeholders::_1));
     }
 
     /*
