@@ -23,9 +23,9 @@
 #ifndef INCLUDED_GSM_GEN_TEST_AB_IMPL_H
 #define INCLUDED_GSM_GEN_TEST_AB_IMPL_H
 
-#include <grgsm/transmitter/gen_test_ab.h>
-#include <grgsm/misc_utils/time_spec.h>
-#include <grgsm/misc_utils/fn_time.h>
+#include <gsm/transmitter/gen_test_ab.h>
+#include <gsm/misc_utils/time_spec.h>
+#include <gsm/misc_utils/fn_time.h>
 
 namespace gr {
   namespace gsm {
