@@ -26,8 +26,8 @@
 #endif
 
 #include <gnuradio/io_signature.h>
-#include <grgsm/endian.h>
-#include <grgsm/gsmtap.h>
+#include <gsm/endian.h>
+#include <gsm/gsmtap.h>
 
 #include "txtime_setter_impl.h"
 
@@ -76,10 +76,10 @@ namespace gr {
         // Bind message handlers
         set_msg_handler(pmt::mp("fn_time"),
           boost::bind(&txtime_setter_impl::process_fn_time_reference,
-            this, _1));
+            this, boost::placeholders::_1));
         set_msg_handler(pmt::mp("bursts_in"),
           boost::bind(&txtime_setter_impl::process_txtime_of_burst,
-            this, _1));
+            this, boost::placeholders::_1));
     }
 
     /*
