@@ -33,9 +33,6 @@ if "CMAKE_BINARY_DIR" in os.environ:
     # not able to load the modules using the relative import syntax and grcc compilation and
     # some unit tests fail.
     __path__ += [
-        # Load the local (not yet installed) grgsm_swig from the ../swig subdirectory.
-        os.path.join(os.environ.get("CMAKE_BINARY_DIR"), "swig"),
-
         # Load the local (not yet installed) python modules from the local subdirectories
         os.path.join(dirname, "misc_utils"),
         os.path.join(dirname, "receiver"),
@@ -43,16 +40,21 @@ if "CMAKE_BINARY_DIR" in os.environ:
         os.path.join(dirname, "transmitter"),
         os.path.join(dirname, "trx")]
 
+# import pybind11 generated symbols into the gsm namespace
 try:
-    # import swig generated symbols into the gsm namespace
-    from .grgsm_swig import *
+    # this might fail if the module is python-only
+    from .gsm_python import *
+except ModuleNotFoundError:
+    pass
 
+try:
     # import any pure python here
 
     #from fcch_burst_tagger import fcch_burst_tagger
     #from sch_detector import sch_detector
     #from fcch_detector import fcch_detector
     from .clock_offset_corrector_tagged import clock_offset_corrector_tagged
+    from .multiarfcns_receiver import multiarfcns_receiver
     from .gsm_input import gsm_input
     from .gsm_bcch_ccch_demapper import gsm_bcch_ccch_demapper
     from .gsm_bcch_ccch_sdcch4_demapper import gsm_bcch_ccch_sdcch4_demapper
